@@ -1,6 +1,6 @@
 from flask import Blueprint, request
 from flask_restful import Resource, Api
-from .common import Status, WorkMode, Manifest
+from .common import Status, WorkMode, Manifest, DiffMode
 from .flow import Flow, FlowList
 from .mock import MockData, MockGroup, ActivatedMockGroup, MockGroupByName
 from .config import Conf, ResetConf
@@ -15,7 +15,7 @@ from .qrcode import Qrcode
 from .search import SearchMockDataByName
 from .bandwidth import Bandwidth, BandwidthTemplates
 from .status_bar import StatusBar
-from .snapshot_import import SanpshotImport
+from .snapshot_import import SanpshotImport, SnapShotImportDetail
 from .snapshot_export import SnapshotExportFromDM, SnapshotExportFromEvent
 from lyrebird.log import get_logger
 from lyrebird import application
@@ -63,6 +63,7 @@ api_source.add_resource(Qrcode, '/qrcode')
 api_source.add_resource(Conf, '/conf/<string:plugin_name>')
 api_source.add_resource(ResetConf, '/conf/<string:plugin_name>/reset')
 api_source.add_resource(WorkMode, '/mode', '/mode/<string:mode>')
+api_source.add_resource(DiffMode, '/diffmode')
 api_source.add_resource(Plugin, '/plugin', '/plugin/<string:plugin_name>')
 api_source.add_resource(Menu, '/menu')
 api_source.add_resource(Notice, '/notice')
@@ -71,7 +72,8 @@ api_source.add_resource(Bandwidth, '/bandwidth')
 api_source.add_resource(BandwidthTemplates, '/bandwidth_templates')
 api_source.add_resource(SanpshotImport, '/snapshot/import/<path:url>', '/snapshot/import')
 api_source.add_resource(SnapshotExportFromDM,  '/snapshot/export/dm')
-api_source.add_resource(SnapshotExportFromEvent,  '/snapshot/export/event')
+api_source.add_resource(SnapshotExportFromEvent, '/snapshot/export/event')
+api_source.add_resource(SnapShotImportDetail, '/snapshot/detail')
 api_source.add_resource(
     Event,
     '/event',
